import { BigNumber, BigNumberish, ethers, Signer } from 'ethers';
import { Provider, TransactionReceipt } from '@ethersproject/providers';
import { ItemListing as ItemListingContract } from '@motif-foundation/listing/dist/typechain';
export interface Listing {
    approved: boolean;
    amount: BigNumber;
    duration: BigNumber;
    firstBidTime: BigNumber;
    reservePrice: BigNumber;
    curatorFeePercentage: number;
    tokenOwner: string;
    bidder: string;
    curator: string;
    listingCurrency: string;
}
export declare class ItemListing {
    readonly chainId: number;
    readonly readOnly: boolean;
    readonly signerOrProvider: Signer | Provider;
    readonly itemListing: ItemListingContract;
    readonly motifAddress: string;
    constructor(signerOrProvider: Signer | Provider, chainId: number);
    fetchListing(listingId: BigNumberish): Promise<Listing>;
    fetchListingFromTransactionReceipt(receipt: TransactionReceipt): Promise<Listing | null>;
    createListing(tokenId: BigNumberish, duration: BigNumberish, reservePrice: BigNumberish, curator: string, curatorFeePercentages: number, listingCurrency: string, tokenAddress?: string): Promise<ethers.ContractTransaction>;
    setListingApproval(listingId: BigNumberish, approved: boolean): Promise<ethers.ContractTransaction>;
    setListingReservePrice(listingId: BigNumberish, reservePrice: BigNumberish): Promise<ethers.ContractTransaction>;
    createBid(listingId: BigNumberish, amount: BigNumberish): Promise<ethers.ContractTransaction>;
    endListing(listingId: BigNumberish): Promise<ethers.ContractTransaction>;
    cancelListing(listingId: BigNumberish): Promise<ethers.ContractTransaction>;
}
